#! /usr/bin/python3

# Script properties for internal functions
cycletime = 1400										    	# Node polling cycle time
pollinggap = 3											    	# Polling interval between nodes
			# (num of nodes) * (pollinggap) = (minimum cycle time)
active_time = '19:30'										    # Lantern ON reference time
GPS_poll_time = '01:00'										    # GPS Mapping start reference time
inactive_time = '06:46'										    # Lantern OFF reference time
LM_active_time = '19:00'									    # Manual overriding reference ON time
node_off_time = '07:00'										    # Manual overriding reference OFF time
aggressive_poll_duration_mins = 90								# Aggressive polling duration for nodes starting from active_time
minimum_power = 15.0										    # Power check for lantern if Lantern is OFF during active hours 
max_msgID_count = 250                                           # Max MsgID implemented

# HTTP/MQTT-related variables
test_align_flag = False
cert_codename = 'dbkl'
topic_header = 'nodes/data/'                                    # MQTT topic header
client_ID = 'INSERTTOPIC1HERE'                                  # client ID for first instance
client_ID_2 = 'INSERTTOPIC2HERE'								# client ID for second instance (normally not used unless dual-polling required, run PYGatewayListener_v1.0_2)

# Static gateway and database specs
localDBpath = 'INSERTCSVNAMEHERE.csv'			    		    # Local deploy node list file in RaspPi
first_GW_data = ('FE01', '1001', '20')                          # First gateway node specifications
second_GW_data = ('FE02', '1001', '20')                         # Second gateway node specifications

# Auto-generated files repositories
problemlogpath = 'errorlog'
logfilepath = 'log'                                 		    # Local log repository
maplogpath = 'GPSlog'					    		    		# Daily map repository
GPS_style1 = ['downArrowIcon', 'http://maps.google.com/mapfiles/kml/pal4/icon28.png']       	    # Represents '#G0!' on map 
GPS_style2 = ['whiteBlankIcon', 'http://maps.google.com/mapfiles/kml/paddle/wht-blank.png'] 	    # Represents '#G0-' on map
GPS_style3 = ['redStarIcon', 'http://maps.google.com/mapfiles/kml/paddle/red-stars.png']    	    # Represents '#G0|V|' and '#G0|V|NoFix' on map

# Packet structures
msgID = 'XXXXX'											    	# Message ID length
msgID_vers = 1                                                  # Max version implemented on msgID
nodeID = 'XXXX'                                                 # Node ID length


#! /usr/bin/python3

import os
import subprocess
import fcntl
import logging
from logging import handlers
import sys
import time
try:
	import config_PYproperties
except:
	print('Script configurations not set, script is not executed.')
	sys.exit(1)

file_pathname = str(os.path.abspath(os.path.dirname(sys.argv[0])))
problemlogpath = file_pathname + '/' + config_PYproperties.problemlogpath
logfilepath = file_pathname + '/' + config_PYproperties.logfilepath
CONST_USB_DEV_FS_RESET_CODE = ord('U') << (4*2) | 20
USB_CONVERTER_NAME = 'CP210x'
if __name__ == '__main__':
	my_logger = logging.getLogger('PacketListener')
	my_logger.setLevel(logging.DEBUG)
	my_logger_problem = logging.getLogger('MainReset')
	my_logger_problem.setLevel(logging.DEBUG)
	formatter_simplelog = logging.Formatter('%(threadName)s:%(asctime)s - %(message)s\n', datefmt='%Y-%m-%d,%H:%M:%S')
	formatter_stdo = logging.Formatter('%(asctime)s  %(threadName)s:%(lineno)d - %(message)s\n', datefmt='%Y-%m-%d,%H:%M:%S')
	stdoh = logging.StreamHandler(sys.stdout)
	stdoh.setLevel(logging.INFO)
	stdoh.setFormatter(formatter_stdo)
	my_logger.addHandler(stdoh)
	simple_fh = handlers.RotatingFileHandler(logfilepath+'/gateway.log', maxBytes=5000000, backupCount=100)
	simple_fh.setLevel(logging.DEBUG)
	simple_fh.setFormatter(formatter_simplelog)
	my_logger.addHandler(simple_fh)
	problem_fh = handlers.RotatingFileHandler(problemlogpath+'/error.log', maxBytes=500000, backupCount=25)
	problem_fh.setLevel(logging.INFO)
	problem_fh.setFormatter(formatter_simplelog)
	my_logger_problem.addHandler(problem_fh)
	
	final_usb_path_list = []
	proc_1 = subprocess.Popen(['lsusb'], stdout=subprocess.PIPE)
	cmd_output_1 = proc_1.communicate()[0]
	usb_device_list = cmd_output_1.split(b'\n')
	for items in usb_device_list:
		if USB_CONVERTER_NAME.encode('utf-8') in items:
			usb_dev_details = items.split()
			usb_bus = usb_dev_details[1]
			usb_dev = usb_dev_details[3][:3]
			device_path_name = '/dev/bus/usb/' + usb_bus.decode('utf-8') + '/' + usb_dev.decode('utf-8')
			final_usb_path_list.append(device_path_name)
			spec_string = '[HWRESET] - Invoking hardware refresh on bus device ' + device_path_name
			my_logger.debug(spec_string)
	for usb_devices in final_usb_path_list:
		try:
			device_file = os.open(usb_devices, os.O_WRONLY)
			fcntl.ioctl(device_file, CONST_USB_DEV_FS_RESET_CODE, 0)
		except Exception as err:
			my_logger.debug(err)
			my_logger_problem.info(err)
		finally:
			try:
				os.close(device_file)
			except:
				pass
			time.sleep(1)



'''
Created on 12 Jul 2021

@author: -
'''

from setuptools import setup

with open("README.md", "r") as fh:
    description = fh.read()
    
setup(
    name="pyserialgateway",
    version="1.3.19",
    author="ljyee",
    author_email="joeyee@senatraffic.com.my",
    packages=["pyserialgateway"],
    include_package_data=True,
    description="Classes dedicated for multi-functioned processes which includes DB, mapping, data and connection capabilities.",
#     long_description=description,
#     long_description_content_type='text/markdown',
    url='https://github.com/joeyee-senatraffic/pyserialgateway.git',
    license='MIT',
    python_requires='>=3.5',
    install_requires=[
        'pyserial>=3.5',
        'psycopg2>=2.8.5',
        'pykml>=0.2.0',
        'psutil>=5.6.7'
    ]
)